@@ -276,6 +276,10 @@ class _parser(object):
                     setattr(self, attr, int(token))
 
     def _get_period(self):
+        if self.settings.RETURN_TIME_AS_PERIOD:
+            if getattr(self, 'time', None):
+                return 'time'
+
         for period in ['time', 'day']:
             if getattr(self, period, None):
                 return 'day'
@@ -376,7 +380,10 @@ class _parser(object):
                 delta = timedelta(days=steps)
             else:
                 if days[day_index] == day:
-                    steps = 7
+                    if self.settings.PREFER_DATES_FROM == 'past':
+                        steps = 7
+                    else:
+                        steps = 0
                 else:
                     while days[day_index] != day:
                         day_index -= 1
@@ -445,8 +452,9 @@ class _parser(object):
 
         # correction for preference of day: beginning, current, end
         dateobj = po._correct_for_day(dateobj)
+        period = po._get_period()
 
-        return dateobj, po._get_period()
+        return dateobj, period
 
     def _parse(self, type, token, fuzzy, skip_component=None):
 
